@@ -13,13 +13,17 @@ from jaseci.utils.id_list import IdList
 class Architype(Element, JacCode, ArchitypeInterp):
     """Architype class for Jaseci"""
 
-    def __init__(self, code_ir=None, *args, **kwargs):
+    def __init__(self, code_ir=None, is_async=False, *args, **kwargs):
         self.super_archs = list()
         self.anchor_var = None
         self.private_vars = []
         self.entry_action_ids = IdList(self)
         self.activity_action_ids = IdList(self)
         self.exit_action_ids = IdList(self)
+
+        # async handling for walker
+        self.is_async = is_async
+
         Element.__init__(self, *args, **kwargs)
         JacCode.__init__(self, code_ir)
         ArchitypeInterp.__init__(self)
