@@ -14,7 +14,7 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def setUp(self):
         super().setUp()
-        self.sent = Sentinel(m_id="anon", h=MetaService().hook())
+        self.sent = Sentinel(m_id="anon", h=MetaService().build_hook())
         self.gph = Graph(m_id="anon", h=self.sent._h)
         self.old_stdout = sys.stdout
         self.new_stdout = io.StringIO()
